@@ -716,14 +716,14 @@ gwm_desktop_draw (GtkWidget    *widget,
   gtk_draw_box (style,
                 window,
                 GTK_STATE_ACTIVE,
-                current ? GTK_SHADOW_IN : GTK_SHADOW_OUT,
+                current ? GTK_SHADOW_OUT : GTK_SHADOW_ETCHED_IN,
                 0, 0,
                 -1, -1);
   
   /* create gc for current area and draw its background */
   if (desk->n_hareas * desk->n_vareas > 1)
     {
-      GdkGC *gc = (current ? style->bg_gc : style->base_gc)[GTK_STATE_SELECTED];
+      GdkGC *gc = current ? style->bg_gc[GTK_STATE_SELECTED] : style->base_gc[GTK_STATE_NORMAL];
       
       gdk_gc_set_stipple (gc, desktop->bitmap);
       gdk_gc_set_clip_mask (gc, NULL);
@@ -834,7 +834,7 @@ gwm_desktop_draw (GtkWidget    *widget,
   gtk_draw_shadow (style,
                    window,
                    GTK_STATE_ACTIVE,
-                   current ? GTK_SHADOW_IN : GTK_SHADOW_OUT,
+                   current ? GTK_SHADOW_OUT : GTK_SHADOW_ETCHED_IN,
                    0, 0,
                    -1, -1);
 
