@@ -56,6 +56,7 @@ static gulong XA_WM_DELETE_WINDOW = 0;
 static gulong XA_WM_TAKE_FOCUS = 0;
 static gulong XA_ENLIGHTENMENT_DESKTOP = 0;
 static gulong XA_KWM_WIN_ICON = 0;
+static gulong XA_COMPOUND_TEXT = 0;
 
 static const struct {
   gulong      *atom;
@@ -83,6 +84,7 @@ static const struct {
   { &XA_WM_TAKE_FOCUS,			"WM_TAKE_FOCUS", },
   { &XA_ENLIGHTENMENT_DESKTOP,		"ENLIGHTENMENT_DESKTOP", },
   { &XA_KWM_WIN_ICON,                   "KWM_WIN_ICON", },
+  { &XA_COMPOUND_TEXT,                  "COMPOUND_TEXT", },
 };
 
 
@@ -108,6 +110,15 @@ static gboolean		send_client_message_3L	  (Window     recipient,
 						   glong      long1,
 						   glong      long2,
 						   glong      long3);
+static gboolean		send_client_message_5L	  (Window     recipient,
+						   Window     event_window,
+						   Atom       message_type,
+						   long       event_mask,
+						   glong      long1,
+						   glong      long2,
+						   glong      long3,
+						   glong      long4,
+						   glong      long5);
 static void 		get_task_root_and_frame   (GwmhTask    *task);
 static GdkWindow*	gdk_window_ref_from_xid	  (Window       xwin);
 static guint            gwmh_property_atom2info   (Atom         atom,
@@ -373,7 +384,7 @@ get_typed_property_data (Display *xdisplay,
       requested_type != AnyPropertyType &&
       requested_type != type_returned)
     {
-      g_warning (G_GNUC_PRETTY_FUNCTION "(): Property has wrong type, probably on crack");
+      /* g_warning (G_GNUC_PRETTY_FUNCTION "(): Property has wrong type, probably on crack"); */
       abort++;
     }
   if (!abort && bytes_after_return)
@@ -417,10 +428,28 @@ get_typed_property_data (Display *xdisplay,
 	}
       if (!data && *size_p)
 	{
-	  guint8 *mem = g_malloc (*size_p + 1);
+	  guint8 *mem = NULL;
 
-	  memcpy (mem, prop_data, *size_p);
-	  mem[*size_p] = 0;
+	  if (format_returned == 8 && type_returned == XA_COMPOUND_TEXT)
+	    {
+	      gchar **tlist = NULL;
+	      gint count = gdk_text_property_to_text_list (type_returned, 8, prop_data,
+							   nitems_return, &tlist);
+
+	      if (count && tlist && tlist[0])
+		{
+		  mem = g_strdup (tlist[0]);
+		  *size_p = strlen (mem);
+		}
+	      if (tlist)
+		gdk_free_text_list (tlist);
+	    }
+	  if (!mem)
+	    {
+	      mem = g_malloc (*size_p + 1);
+	      memcpy (mem, prop_data, *size_p);
+	      mem[*size_p] = 0;
+	    }
 	  data = mem;
 	}
     }
@@ -488,7 +517,7 @@ send_client_message_2L (Window recipient,
 			glong  long1,
 			glong  long2)
 {
-  return send_client_message_3L (recipient, event_window, message_type, event_mask, long1, long2, 0);
+  return send_client_message_5L (recipient, event_window, message_type, event_mask, long1, long2, 0, 0, 0);
 }
 
 static gboolean
@@ -499,6 +528,20 @@ send_client_message_3L (Window recipient,
 			glong  long1,
 			glong  long2,
 			glong  long3)
+{
+  return send_client_message_5L (recipient, event_window, message_type, event_mask, long1, long2, long3, 0, 0);
+}
+
+static gboolean
+send_client_message_5L (Window recipient,
+			Window event_window,
+			Atom   message_type,
+			long   event_mask,
+			glong  long1,
+			glong  long2,
+			glong  long3,
+			glong  long4,
+			glong  long5)
 {
   XEvent xevent = { 0, };
 
@@ -511,6 +554,8 @@ send_client_message_3L (Window recipient,
   xevent.xclient.data.l[0] = long1;
   xevent.xclient.data.l[1] = long2;
   xevent.xclient.data.l[2] = long3;
+  xevent.xclient.data.l[3] = long4;
+  xevent.xclient.data.l[4] = long5;
 
   gdk_error_trap_push ();
 
@@ -1134,6 +1179,11 @@ gwmh_task_update (GwmhTask        *task,
 				      XA_WM_NAME,
 				      XA_STRING,
 				      &size, 8);
+      if (!name && !size)
+	name = get_typed_property_data (xdisplay, xwindow,
+					XA_WM_NAME,
+					XA_COMPOUND_TEXT,
+					&size, 8);
       if (!gwmh_string_equals (task->name, name))
 	{
 	  g_free (task->name);
@@ -2069,8 +2119,8 @@ gwmh_task_get_mini_icon (GwmhTask   *task,
   Display *xdisplay;
 
   g_return_if_fail (task != NULL);
-  g_return_if_fail (pixmap);
-  g_return_if_fail (mask);
+  g_return_if_fail (pixmap != NULL);
+  g_return_if_fail (mask != NULL);
 
   xdisplay = GDK_WINDOW_XDISPLAY (task->gdkwindow);
 
@@ -2080,32 +2130,40 @@ gwmh_task_get_mini_icon (GwmhTask   *task,
 				      XA_KWM_WIN_ICON,
 				      &size,
 				      32);
-
-  if (atomdata)
+  if (!atomdata || !atomdata[0] || !size)
     {
-      /* Get icon size and depth */
-      XGetGeometry (xdisplay, (Drawable)atomdata[0], &root, &x, &y, 
-		    &width, &height, &b, &depth);
-      
-      /* Create a new GdkPixmap and copy the mini icon pixmap to it */
-      *pixmap = gdk_pixmap_new (NULL, 16, 16, depth);
-      gc = gdk_gc_new (*pixmap);
-      gc_private = (GdkGCPrivate*) gc;
-      private = (GdkPixmapPrivate*) *pixmap;
-      XCopyArea (private->xdisplay, atomdata[0], private->xwindow, gc_private->xgc,
-		 0, 0, width, height, 0, 0);
-      gdk_gc_destroy (gc);
-      
-      /* Create a new GdkBitmap and copy the mini icon mask to it */
-      *mask = gdk_pixmap_new (NULL, 16, 16, 1);
-      gc = gdk_gc_new (*mask);
-      gc_private = (GdkGCPrivate*) gc;
-      private = (GdkPixmapPrivate*) (*mask);
-      XCopyArea (private->xdisplay, atomdata[1], private->xwindow, gc_private->xgc,
-		 0, 0, 16, 16, 0, 0);
-      gdk_gc_destroy (gc);
-      g_free (atomdata);
+      *pixmap = NULL;
+      *mask = NULL;
+
+      return;
     }
+
+  /* Get icon size and depth */
+  XGetGeometry (xdisplay, (Drawable) atomdata[0], &root, &x, &y, 
+		&width, &height, &b, &depth);
+  
+  /* Create a new GdkPixmap and copy the mini icon pixmap to it */
+  *pixmap = gdk_pixmap_new (NULL, width, height, depth);
+  gc = gdk_gc_new (*pixmap);
+  gc_private = (GdkGCPrivate*) gc;
+  private = (GdkPixmapPrivate*) *pixmap;
+  XCopyArea (private->xdisplay, atomdata[0], private->xwindow, gc_private->xgc,
+	     0, 0, width, height, 0, 0);
+  gdk_gc_destroy (gc);
+  
+  /* get mask size and depth */
+  XGetGeometry (xdisplay, (Drawable)atomdata[1], &root, &x, &y, 
+		&width, &height, &b, &depth);
+
+  /* Create a new GdkBitmap and copy the mini icon mask to it */
+  *mask = gdk_pixmap_new (NULL, width, height, 1);
+  gc = gdk_gc_new (*mask);
+  gc_private = (GdkGCPrivate*) gc;
+  private = (GdkPixmapPrivate*) *mask;
+  XCopyArea (private->xdisplay, atomdata[1], private->xwindow, gc_private->xgc,
+	     0, 0, width, height, 0, 0);
+  gdk_gc_destroy (gc);
+  g_free (atomdata);
 }
 
 void
@@ -2142,10 +2200,9 @@ gwmh_task_set_area (GwmhTask *task,
        harea == task->harea &&
        varea == task->varea))
     return;
-
+  
   gwmh_sync ();
-  gwmh_freeze_syncs ();
-
+  
   /* ugly hack for buggy window managers
    * that violate the spec and expect us to modify properties directly
    */
@@ -2159,16 +2216,17 @@ gwmh_task_set_area (GwmhTask *task,
       if (desktop != task->desktop)
 	XChangeProperty (GDK_DISPLAY (), task->xwin, GWMHA_WIN_WORKSPACE,
 			 XA_CARDINAL, 32, PropModeReplace, (unsigned char*) data, 1);
-
+      
       data[0] = harea;
       data[1] = varea;
       XChangeProperty (GDK_DISPLAY (), task->xwin, GWMHA_WIN_AREA,
 		       XA_CARDINAL, 32, PropModeReplace, (unsigned char*) data, 2);
-
+      
       gdk_error_trap_pop ();
     }
   else
     {
+      gwmh_freeze_syncs ();
       if (desktop != task->desktop)
 	send_client_message_2L (GDK_ROOT_WINDOW (), task->xwin,
 				GWMHA_WIN_WORKSPACE,
@@ -2178,9 +2236,8 @@ gwmh_task_set_area (GwmhTask *task,
 			      GWMHA_WIN_AREA,
 			      SubstructureNotifyMask,
 			      harea, varea, CurrentTime);
+      gwmh_thaw_syncs ();
     }
-  
-  gwmh_thaw_syncs ();
 }
 
 void
@@ -2222,6 +2279,26 @@ gwmh_desk_get_config (void)
   return &gwmh_desk;
 }
 
+void
+gwmh_window_send_client_message (GdkWindow *window,
+				 gulong     atom,
+				 gulong	    long1,
+				 gulong	    long2,
+				 gulong	    long3,
+				 gulong	    long4,
+				 gulong	    long5)
+{
+  g_return_if_fail (window != NULL);
+  g_return_if_fail (atom > 0);
+
+  if (!GDK_WINDOW_IS_DESTROYED (window))
+    send_client_message_5L (GDK_ROOT_WINDOW (),
+			    GDK_WINDOW_XWINDOW (window),
+			    atom,
+			    SubstructureNotifyMask,
+			    long1, long2, long3, long4, long5);
+}
+
 void
 gwmh_desk_guess_desktop_area (guint  desktop,
 			      guint *harea,
