@@ -155,7 +155,8 @@ static gboolean menu_tree_move_test_cb(GtkCTree *ctree, GtkCTreeNode *source_nod
 	if (!dd->editable || !dd_parent->editable) return FALSE;
 
 	if (strcmp(dd->path, user_apps_dir) == 0 ||
-	    strcmp(dd->path, system_apps_dir) == 0 ) return FALSE;
+	    strcmp(dd->path, system_apps_dir) == 0 ||
+	    strcmp(dd->path, system_applets_dir) == 0 ) return FALSE;
 
 	if (new_parent != GTK_CTREE_ROW(source_node)->parent)
 		{
