@@ -41,6 +41,10 @@
 #include "cache.h"
 #include "help-browser.h"
 
+#ifdef HELP_USE_GTKHTML
+#include <gtkhtml/gtkhtml.h>
+#endif
+
 extern char *program_invocation_name;
 
 #define NAME "GnomeHelp"
@@ -76,13 +80,14 @@ help_browser_simple_browser
 void destroy_server(HelpWindow win);
 
 /* MANPATH should probably come from somewhere */
-#define DEFAULT_MANPATH "/usr/man:/usr/local/man:/usr/X11R6/man"
-#define DEFAULT_INFOPATH "/usr/info:/usr/local/info"
+#define DEFAULT_MANPATH   GNOME_PREFIX "/man:/usr/man:/usr/local/man:/usr/X11R6/man"
+#define DEFAULT_INFOPATH  GNOME_PREFIX "/info:/usr/info:/usr/local/info"
 /* GHELPPATH probably needs some automatic additions inside toc */
-#define DEFAULT_GHELPPATH GNOMEHELPPATH ":/opt/gnome/share/gnome/help:" \
+#define DEFAULT_GHELPPATH GNOME_PREFIX "/share/gnome/help:" \
+                          "/opt/gnome/share/gnome/help:" \
                           "/usr/local/share/gnome/help:" \
 			  "/usr/local/gnome/share/gnome/help:" \
-			  "/usr/share/gnome/help:" 
+			  "/usr/share/gnome/help" 
 #define DEFAULT_MEMCACHESIZE "1000000"
 #define DEFAULT_HISTORYLENGTH "1000"
 #define HELP_BROWSER_RC_DIR ".gnome-help-browser"
@@ -180,6 +185,11 @@ main(int argc, char *argv[])
     orb = gnome_CORBA_init_with_popt_table(NAME, VERSION, &argc, argv,
 					   options, 0, &ctx, GNORBA_INIT_SERVER_FUNC, &ev);
 
+    gdk_rgb_init ();
+ 
+    gtk_widget_set_default_colormap (gdk_rgb_get_cmap ());
+    gtk_widget_set_default_visual (gdk_rgb_get_visual ());
+
     leftovers = poptGetArgs(ctx);
     if(leftovers && leftovers[0]) {
       helpURL = leftovers[0];
@@ -237,7 +247,7 @@ main(int argc, char *argv[])
     Exception(&ev);
 
     goad_server_register(NULL, browser_object, "gnome-help-browser", "object", &ev);
-
+#if 0
     /* define if you need to debug output, else squelch it */
 #ifdef CREATE_LOGFILE
     output_fd = open("/tmp/gnome-help-browser.log", O_CREAT | O_WRONLY
@@ -250,7 +260,7 @@ main(int argc, char *argv[])
     dup2(output_fd, fileno(stdout));
     dup2(output_fd, fileno(stderr));
     close(output_fd);
-
+#endif
     gtk_main();
 
     saveHistory(historyWindow);
