@@ -53,24 +53,28 @@ GtkType drawer_pos_get_type (void);
 GtkWidget *drawer_widget_new (PanelOrientType orient,
 			      BasePMode mode,
 			      BasePState state,
-			      PanelSizeType sz,
+			      int sz,
 			      int hidebuttons_enabled,
 			      int hidebutton_pixmap_enabled,
 			      PanelBackType back_type,
 			      char *back_pixmap,
-			      int fit_pixmap_bg,
+			      gboolean fit_pixmap_bg,
+			      gboolean strech_pixmap_bg,
+			      gboolean rotate_pixmap_bg,
 			      GdkColor *back_color);
 
 void drawer_widget_change_params (DrawerWidget *drawer,
 				  PanelOrientType orient,
 				  BasePMode mode,
 				  BasePState state,
-				  PanelSizeType sz,
+				  int sz,
 				  int hidebuttons_enabled,
 				  int hidebutton_pixmap_enabled,
 				  PanelBackType back_type,
 				  char *back_pixmap,
-				  int fit_pixmap_bg,
+				  gboolean fit_pixmap_bg,
+				  gboolean strech_pixmap_bg,
+				  gboolean rotate_pixmap_bg,
 				  GdkColor *back_color);
 
 void drawer_widget_change_orient (DrawerWidget *drawer,
