@@ -12,8 +12,8 @@
 
 BEGIN_GNOME_DECLS
 
-void load_logout_applet(PanelWidget *panel, int pos);
-void load_lock_applet(PanelWidget *panel, int pos);
+void load_logout_applet(PanelWidget *panel, int pos, gboolean exactpos);
+void load_lock_applet(PanelWidget *panel, int pos, gboolean exactpos);
 
 END_GNOME_DECLS
 
