@@ -33,6 +33,8 @@ GtkWidget * create_icon_entry(GtkWidget *table,
 			      char *text,
 			      GtkWidget *w);
 
+void panel_pbox_help_cb (GtkWidget *, gint, gpointer);
+
 GList * my_g_list_swap_next(GList *list, GList *dl);
 GList * my_g_list_swap_prev(GList *list, GList *dl);
 /*maybe this should be a glib function?
@@ -61,6 +63,9 @@ gboolean convert_string_to_keysym_state(char *string,
 char * convert_keysym_state_to_string(guint keysym,
 				      guint state);
 
+void panel_set_dialog_layer(GtkWidget *dialog);
+GtkWidget *panel_error_dialog(char *format, ...) G_GNUC_PRINTF (1, 2);
+
 
 END_GNOME_DECLS
 
